@@ -39,8 +39,11 @@ service_yaml_schema = {
         "migrations" : {
             "type" : "boolean"
         },
+        "sfsp" : {
+            "type" : "boolean"
+        },
     },
-    "required": ["name", "type", "deploy", "stages", "regions", "migrations"]
+    "required": ["name", "type", "deploy", "stages", "regions", "migrations", "sfsp"]
 }
 
 if aws_profile or (aws_access_key_id and aws_secret_access_key):
@@ -163,6 +166,13 @@ def sls_migrate(stage, region, chdir_path, function, data):
     run_bash(command)
     os.chdir(cwd)
 
+def sls_sfsp(stage, region, chdir_path):
+    cwd = os.getcwd()
+    os.chdir(chdir_path)
+    command=f'sls sfsp --stage={stage} --region={region}'
+    run_bash(command)
+    os.chdir(cwd)
+
 def populate_git_traits(service, branch, commit, version, author):
     service["branch"] = branch if branch else git_branch
     service["commit"] = commit if branch else git_commit
@@ -215,6 +225,36 @@ def deploy_service_cmd(stage, region, args, service_dir, branch, commit, version
         service["after_deploy_timestamp"] = int(timestamps[0])
         write_traits_to_file(service, traits_output_file)
 
+@cli.command("sfsp")
+@click.option('-r', '--region', required=True, type=str, help='Deployment region')
+@click.option('-s', '--stage', required=True, type=str, help='Deployment stage')
+@click.option('--service-dir', type=str, default='.', help='Service directory where to run sls rollback')
+@click.option('--traits-input-file', type=str, default='traits.yml', help='Load traits file. Default (traits.yml)')
+@click.option('--traits-output-file', type=str, default='traits.yml', help='Updated traits file. Default (traits.yml)')
+def sfsp_cmd(stage, region, service_dir, traits_input_file, traits_output_file):
+    service = load_traits_from_file(traits_input_file)
+    service["sfsp_status"] = False
+    service["sfsp_run"] = False
+    service["sfsp_timestamp"] = ''
+    write_traits_to_file(service, traits_output_file)
+
+    if service["sfsp"] == False:
+        logging.warning(f'Service ({service["name"]}) has no "sfsp" in traits file')
+        logging.warning(f'Skipping sfsp...')
+        sys.exit(0)
+
+    logging.info(f'Running sfsp for service ({service["name"]})...')
+    service["sfsp_run"] = True
+    write_traits_to_file(service, traits_output_file)
+    sls_sfsp(stage, region, service_dir)
+
+    service["sfsp_status"] = True
+    write_traits_to_file(service, traits_output_file)
+
+    timestamp = datetime.now(timezone.utc).replace(tzinfo=timezone.utc).timestamp()
+    logging.info(f'Sfsp timestamp: {str(timestamp)}')
+    service["sfsp_timestamp"] = timestamp
+    write_traits_to_file(service, traits_output_file)
 
 @cli.command("rollback-service")
 @click.option('-r', '--region', required=True, type=str, help='Deployment region')
